"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.assertPageIsAccessible = assertPageIsAccessible;
const playwright_1 = __importDefault(require("@axe-core/playwright"));
const test_1 = require("@playwright/test");
const axe_html_reporter_1 = require("axe-html-reporter");
/**
 * Test the accessibility of a page, generate a HTML report and attach
 *
 * @param page - The Page object for the test
 * @param testInfo - The testInfo object
 * @param results - AxeBuilder Results if tested outside the method
 *
 * @returns void
 */
async function assertPageIsAccessible(page, testInfo, results) {
    // Generate reults if not passed in
    if (!results) {
        results = await new playwright_1.default({ page }).analyze();
    }
    // Generate a HTML report
    (0, axe_html_reporter_1.createHtmlReport)({
        results,
        options: {
            outputDir: 'playwright-report/data'
        },
    });
    // Attach the report
    await testInfo.attach('accessibility-scan-results', {
        path: 'playwright-report/data/accessibilityReport.html',
    });
    (0, test_1.expect)(results.violations).toEqual([]);
}
//# sourceMappingURL=accessibility.spec.js.map